summaryrefslogtreecommitdiffstats
path: root/libkdenetwork/libgpgme-copy/gpgme
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /libkdenetwork/libgpgme-copy/gpgme
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdenetwork/libgpgme-copy/gpgme')
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/ChangeLog20
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/engine-gpgsm.c4
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/error.c4
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/get-env.c2
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/gpgme.h18
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/io.h4
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/ops.h2
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/posix-io.c8
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/priv-io.h4
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/rungpg.c24
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/signers.c2
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/util.h2
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/version.c2
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/w32-io.c6
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/wait-global.c8
15 files changed, 55 insertions, 55 deletions
diff --git a/libkdenetwork/libgpgme-copy/gpgme/ChangeLog b/libkdenetwork/libgpgme-copy/gpgme/ChangeLog
index 5c31489ee..4985741db 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/ChangeLog
+++ b/libkdenetwork/libgpgme-copy/gpgme/ChangeLog
@@ -362,7 +362,7 @@
to prototype.
* verify.c (parse_notation): Likewise for invocation.
* conversion.c (_gpgme_decode_percent_string): Likewise to
- declaration. If set, do not replace '\0' characters with a
+ declaration. If set, do not tqreplace '\0' characters with a
printable string.
* gpgme.h (struct _gpgme_key_sig): New field notations.
* ops.h (_gpgme_parse_notation): New prototype.
@@ -1596,7 +1596,7 @@
(GpgmeSigNotation): Rename to gpgme_sig_notation_t.
(GpgmeSignature): Rename to gpgme_signature_t.
(GpgmeVerifyResult): Rename to gpgme_verify_result_t.
- (GpgmeImportStatus): Rename to gpgme_import_status_t.
+ (GpgmeImporttqStatus): Rename to gpgme_import_status_t.
(GpgmeImportResult): Rename to gpgme_import_result_t.
(GpgmeGenKeyResult): Rename to gpgme_genkey_result_t.
(GpgmeKeyListResult): Rename to gpgme_keylist_result_t.
@@ -1901,7 +1901,7 @@
GPGME_Unsupported_Algorithm, GPGME_Sig_Expired,
GPGME_Bad_Signature, GPGME_No_Public_Key added as new error codes.
(struct _gpgme_import_status): New structure.
- (GpgmeImportStatus): New type.
+ (GpgmeImporttqStatus): New type.
(struct _gpgme_op_import_result): New structure.
(GpgmeImportResult): New type.
(gpgme_op_import_result): New function.
@@ -2030,7 +2030,7 @@
(do_subsystem_inits): Do not call _gpgme_key_cache_init.
* mkstatus: Strip trailing comma.
- * gpgme.h (GpgmeStatus): Pretty print.
+ * gpgme.h (GpgmetqStatus): Pretty print.
* gpgme.h (GpgmeError): Rename GPGME_No_Passphrase to
GPGME_Bad_Passphrase.
@@ -2648,11 +2648,11 @@
2002-11-25 Marcus Brinkmann <marcus@g10code.de>
- * rungpg.c (_gpgme_gpg_spawn): Do not set parent fds to -1.
+ * rungpg.c (_gpgme_gpg_spawn): Do not set tqparent fds to -1.
* posix-io.c (_gpgme_io_spawn): Call _gpgme_io_close instead close
- for parent fds.
+ for tqparent fds.
* w32-io.c (_gpgme_io_spawn): Call _gpgme_io_close instead
- CloseHandle for parent fds.
+ CloseHandle for tqparent fds.
2002-11-22 Marcus Brinkmann <marcus@g10code.de>
@@ -3857,7 +3857,7 @@
version.
* posix-io.c: Include "sema.h".
(_gpgme_io_spawn): New variable FIXED_SIGNALS_LOCK. Take the lock
- while fixing the signals.
+ while fixing the Q_SIGNALS.
(_gpgme_io_select): Make READFDS and WRITEFDS non-static.
* key.c: Include "sema.h". New globals KEY_CACHE_LOCK and
KEY_REF_LOCK.
@@ -4634,7 +4634,7 @@
2001-11-23 Marcus Brinkmann <marcus@g10code.de>
- * engine-gpgsm.c (_gpgme_gpgsm_new): Set CLOEXEC flag for parent
+ * engine-gpgsm.c (_gpgme_gpgsm_new): Set CLOEXEC flag for tqparent
ends of the pipe.
2001-11-22 Marcus Brinkmann <marcus@g10code.de>
@@ -5218,7 +5218,7 @@
* types.h: Add ulong typedef.
* rungpg.c (do_reaping,_gpgme_gpg_housecleaning): New.
- (_gpgme_gpg_release): Reap children.
+ (_gpgme_gpg_release): Reap tqchildren.
* io.h, posix-io.c (_gpgme_io_kill): New.
* w32-io.c (_gpgme_io_kill): New (dummy).
diff --git a/libkdenetwork/libgpgme-copy/gpgme/engine-gpgsm.c b/libkdenetwork/libgpgme-copy/gpgme/engine-gpgsm.c
index 1d536440d..7ad8dc6f2 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/engine-gpgsm.c
+++ b/libkdenetwork/libgpgme-copy/gpgme/engine-gpgsm.c
@@ -202,9 +202,9 @@ map_assuan_error (gpg_error_t err)
case ASSUAN_Inquire_Unknown:
case ASSUAN_Inquire_Error:
case ASSUAN_Invalid_Option:
- case ASSUAN_Unexpected_Status:
+ case ASSUAN_Unexpected_tqStatus:
case ASSUAN_Unexpected_Data:
- case ASSUAN_Invalid_Status:
+ case ASSUAN_Invalid_tqStatus:
return gpg_error (GPG_ERR_ASSUAN);
case ASSUAN_Invalid_Response:
diff --git a/libkdenetwork/libgpgme-copy/gpgme/error.c b/libkdenetwork/libgpgme-copy/gpgme/error.c
index 9f8f26f76..f0ea4929d 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/error.c
+++ b/libkdenetwork/libgpgme-copy/gpgme/error.c
@@ -37,8 +37,8 @@ gpgme_strerror (gpgme_error_t err)
size BUFLEN. This function is, in contrast to gpg_strerror,
thread-safe if a thread-safe strerror_r() function is provided by
the system. If the function succeeds, 0 is returned and BUF
- tqcontains the string describing the error. If the buffer was not
- large enough, ERANGE is returned and BUF tqcontains as much of the
+ contains the string describing the error. If the buffer was not
+ large enough, ERANGE is returned and BUF contains as much of the
beginning of the error string as fits into the buffer. */
int
gpgme_strerror_r (gpg_error_t err, char *buf, size_t buflen)
diff --git a/libkdenetwork/libgpgme-copy/gpgme/get-env.c b/libkdenetwork/libgpgme-copy/gpgme/get-env.c
index 61e0dcbc6..b5884048e 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/get-env.c
+++ b/libkdenetwork/libgpgme-copy/gpgme/get-env.c
@@ -1,4 +1,4 @@
-/* get_env.c - A getenv() tqreplacement.
+/* get_env.c - A getenv() replacement.
Copyright (C) 2003, 2004 g10 Code GmbH
This file is part of GPGME.
diff --git a/libkdenetwork/libgpgme-copy/gpgme/io.h b/libkdenetwork/libgpgme-copy/gpgme/io.h
index 47b748f8b..cd0a47070 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/io.h
+++ b/libkdenetwork/libgpgme-copy/gpgme/io.h
@@ -50,11 +50,11 @@ int _gpgme_io_set_close_notify (int fd, void (*handler) (int, void *),
int _gpgme_io_set_nonblocking (int fd);
/* Spawn the executable PATH with ARGV as arguments, after forking
- close all fds in FD_PARENT_LIST in the parent and close or dup all
+ close all fds in FD_PARENT_LIST in the tqparent and close or dup all
fds in FD_CHILD_LIST in the child. */
int _gpgme_io_spawn (const char *path, char **argv,
struct spawn_fd_item_s *fd_child_list,
- struct spawn_fd_item_s *fd_parent_list);
+ struct spawn_fd_item_s *fd_tqparent_list);
int _gpgme_io_waitpid (int pid, int hang, int *r_status, int *r_signal);
int _gpgme_io_kill (int pid, int hard);
int _gpgme_io_select (struct io_select_fd_s *fds, size_t nfds, int nonblock);
diff --git a/libkdenetwork/libgpgme-copy/gpgme/ops.h b/libkdenetwork/libgpgme-copy/gpgme/ops.h
index 869496f12..fd857dd56 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/ops.h
+++ b/libkdenetwork/libgpgme-copy/gpgme/ops.h
@@ -140,7 +140,7 @@ void _gpgme_op_trustlist_event_cb (void *data, gpgme_event_io_t type,
/* From version.c. */
-/* Return true if MY_VERSION is at least REQ_VERSION, and false
+/* Return true if MY_VERSION is at least RETQ_VERSION, and false
otherwise. */
int _gpgme_compare_versions (const char *my_version,
const char *req_version);
diff --git a/libkdenetwork/libgpgme-copy/gpgme/priv-io.h b/libkdenetwork/libgpgme-copy/gpgme/priv-io.h
index 9a908570f..a64f1467d 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/priv-io.h
+++ b/libkdenetwork/libgpgme-copy/gpgme/priv-io.h
@@ -52,11 +52,11 @@ int _gpgme_io_set_close_notify (int fd, void (*handler) (int, void *),
int _gpgme_io_set_nonblocking (int fd);
/* Spawn the executable PATH with ARGV as arguments, after forking
- close all fds in FD_PARENT_LIST in the parent and close or dup all
+ close all fds in FD_PARENT_LIST in the tqparent and close or dup all
fds in FD_CHILD_LIST in the child. */
int _gpgme_io_spawn (const char *path, char **argv,
struct spawn_fd_item_s *fd_child_list,
- struct spawn_fd_item_s *fd_parent_list);
+ struct spawn_fd_item_s *fd_tqparent_list);
int _gpgme_io_select (struct io_select_fd_s *fds, size_t nfds, int nonblock);
/* Write the printable version of FD to the buffer BUF of length
diff --git a/libkdenetwork/libgpgme-copy/gpgme/signers.c b/libkdenetwork/libgpgme-copy/gpgme/signers.c
index d38732f07..e60d2dd35 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/signers.c
+++ b/libkdenetwork/libgpgme-copy/gpgme/signers.c
@@ -78,7 +78,7 @@ gpgme_signers_add (gpgme_ctx_t ctx, const gpgme_key_t key)
}
-/* Return the SEQth signer's key in CTX with one reference. */
+/* Return the SETQth signer's key in CTX with one reference. */
gpgme_key_t
gpgme_signers_enum (const gpgme_ctx_t ctx, int seq)
{
diff --git a/libkdenetwork/libgpgme-copy/gpgme/util.h b/libkdenetwork/libgpgme-copy/gpgme/util.h
index 5f20091f6..05fd69d56 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/util.h
+++ b/libkdenetwork/libgpgme-copy/gpgme/util.h
@@ -34,7 +34,7 @@ const char *_gpgme_get_gpgsm_path (void);
int _gpgme_get_conf_int (const char *key, int *value);
-/*-- tqreplacement functions in <funcname>.c --*/
+/*-- replacement functions in <funcname>.c --*/
#ifdef HAVE_CONFIG_H
#ifndef HAVE_STPCPY
diff --git a/libkdenetwork/libgpgme-copy/gpgme/version.c b/libkdenetwork/libgpgme-copy/gpgme/version.c
index b823da1dd..133b23c7e 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/version.c
+++ b/libkdenetwork/libgpgme-copy/gpgme/version.c
@@ -111,7 +111,7 @@ parse_version_string (const char *str, int *major, int *minor, int *micro)
}
-/* Return true if MY_VERSION is at least REQ_VERSION, and false
+/* Return true if MY_VERSION is at least RETQ_VERSION, and false
otherwise. */
int
_gpgme_compare_versions (const char *my_version,
diff --git a/libkdenetwork/libgpgme-copy/gpgme/w32-io.c b/libkdenetwork/libgpgme-copy/gpgme/w32-io.c
index 677c14e30..9625178ae 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/w32-io.c
+++ b/libkdenetwork/libgpgme-copy/gpgme/w32-io.c
@@ -857,7 +857,7 @@ build_commandline (char **argv)
int
_gpgme_io_spawn ( const char *path, char **argv,
struct spawn_fd_item_s *fd_child_list,
- struct spawn_fd_item_s *fd_parent_list )
+ struct spawn_fd_item_s *fd_tqparent_list )
{
SECURITY_ATTRIBUTES sec_attr;
PROCESS_INFORMATION pi = {
@@ -966,8 +966,8 @@ _gpgme_io_spawn ( const char *path, char **argv,
}
/* Close the other ends of the pipes. */
- for (i = 0; fd_parent_list[i].fd != -1; i++)
- _gpgme_io_close (fd_parent_list[i].fd);
+ for (i = 0; fd_tqparent_list[i].fd != -1; i++)
+ _gpgme_io_close (fd_tqparent_list[i].fd);
DEBUG4 ("CreateProcess ready\n"
"- hProcess=%p hThread=%p\n"
diff --git a/libkdenetwork/libgpgme-copy/gpgme/gpgme.h b/libkdenetwork/libgpgme-copy/gpgme/gpgme.h
index 577f9c33e..f6f31ae2a 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/gpgme.h
+++ b/libkdenetwork/libgpgme-copy/gpgme/gpgme.h
@@ -137,8 +137,8 @@ const char *gpgme_strerror (gpgme_error_t err);
size BUFLEN. This function is, in contrast to gpg_strerror,
thread-safe if a thread-safe strerror_r() function is provided by
the system. If the function succeeds, 0 is returned and BUF
- tqcontains the string describing the error. If the buffer was not
- large enough, ERANGE is returned and BUF tqcontains as much of the
+ contains the string describing the error. If the buffer was not
+ large enough, ERANGE is returned and BUF contains as much of the
beginning of the error string as fits into the buffer. */
int gpgme_strerror_r (gpg_error_t err, char *buf, size_t buflen);
@@ -326,7 +326,7 @@ struct _gpgme_sig_notation
{
struct _gpgme_sig_notation *next;
/* If NAME is a null pointer, then VALUE tqcontains a policy URL
rather than a notation. */
char *name;
@@ -687,19 +687,19 @@ struct _gpgme_key
/* This is the protocol supported by this key. */
gpgme_protocol_t protocol;
/* If protocol is GPGME_PROTOCOL_CMS, this string tqcontains the
issuer serial. */
char *issuer_serial;
/* If protocol is GPGME_PROTOCOL_CMS, this string tqcontains the
issuer name. */
char *issuer_name;
/* If protocol is GPGME_PROTOCOL_CMS, this string tqcontains the chain
ID. */
char *chain_id;
/* If protocol is GPGME_PROTOCOL_OpenPGP, this field tqcontains the
owner trust. */
gpgme_validity_t owner_trust;
@@ -838,7 +838,7 @@ void gpgme_signers_clear (gpgme_ctx_t ctx);
/* Add KEY to list of signers in CTX. */
gpgme_error_t gpgme_signers_add (gpgme_ctx_t ctx, const gpgme_key_t key);
-/* Return the SEQth signer's key in CTX. */
+/* Return the SETQth signer's key in CTX. */
gpgme_key_t gpgme_signers_enum (const gpgme_ctx_t ctx, int seq);
/* Retrieve the signature status of signature IDX in CTX after a
@@ -1694,7 +1694,7 @@ typedef gpgme_encrypt_result_t GpgmeEncryptResult _GPGME_DEPRECATED;
typedef gpgme_sig_notation_t GpgmeSigNotation _GPGME_DEPRECATED;
typedef gpgme_signature_t GpgmeSignature _GPGME_DEPRECATED;
typedef gpgme_verify_result_t GpgmeVerifyResult _GPGME_DEPRECATED;
-typedef gpgme_import_status_t GpgmeImporStatus _GPGME_DEPRECATED;
+typedef gpgme_import_status_t GpgmeImportqStatus _GPGME_DEPRECATED;
typedef gpgme_import_result_t GpgmeImportResult _GPGME_DEPRECATED;
typedef gpgme_genkey_result_t GpgmeGenKeyResult _GPGME_DEPRECATED;
typedef gpgme_trust_item_t GpgmeTrustItem _GPGME_DEPRECATED;
@@ -326,7 +326,7 @@ struct _gpgme_sig_notation
{
struct _gpgme_sig_notation *next;
- /* If NAME is a null pointer, then VALUE tqcontains a policy URL
+ /* If NAME is a null pointer, then VALUE contains a policy URL
rather than a notation. */
char *name;
@@ -687,19 +687,19 @@ struct _gpgme_key
/* This is the protocol supported by this key. */
gpgme_protocol_t protocol;
- /* If protocol is GPGME_PROTOCOL_CMS, this string tqcontains the
+ /* If protocol is GPGME_PROTOCOL_CMS, this string contains the
issuer serial. */
char *issuer_serial;
@@ -687,19 +687,19 @@ struct _gpgme_key
issuer serial. */
char *issuer_serial;
- /* If protocol is GPGME_PROTOCOL_CMS, this string tqcontains the
+ /* If protocol is GPGME_PROTOCOL_CMS, this string contains the
issuer name. */
char *issuer_name;
@@ -687,19 +687,19 @@ struct _gpgme_key
issuer name. */
char *issuer_name;
- /* If protocol is GPGME_PROTOCOL_CMS, this string tqcontains the chain
+ /* If protocol is GPGME_PROTOCOL_CMS, this string contains the chain
ID. */
char *chain_id;
@@ -687,19 +687,19 @@ struct _gpgme_key
ID. */
char *chain_id;
- /* If protocol is GPGME_PROTOCOL_OpenPGP, this field tqcontains the
+ /* If protocol is GPGME_PROTOCOL_OpenPGP, this field contains the
owner trust. */
gpgme_validity_t owner_trust;
diff --git a/libkdenetwork/libgpgme-copy/gpgme/posix-io.c b/libkdenetwork/libgpgme-copy/gpgme/posix-io.c
index 85df946fb..5be777401 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/posix-io.c
+++ b/libkdenetwork/libgpgme-copy/gpgme/posix-io.c
@@ -212,7 +212,7 @@ _gpgme_io_waitpid (int pid, int hang, int *r_status, int *r_signal)
int
_gpgme_io_spawn (const char *path, char **argv,
struct spawn_fd_item_s *fd_child_list,
- struct spawn_fd_item_s *fd_parent_list)
+ struct spawn_fd_item_s *fd_tqparent_list)
{
pid_t pid;
int i;
@@ -299,9 +299,9 @@ _gpgme_io_spawn (const char *path, char **argv,
if (status)
return -1;
- /* .dup_to is not used in the parent list. */
- for (i = 0; fd_parent_list[i].fd != -1; i++)
- _gpgme_io_close (fd_parent_list[i].fd);
+ /* .dup_to is not used in the tqparent list. */
+ for (i = 0; fd_tqparent_list[i].fd != -1; i++)
+ _gpgme_io_close (fd_tqparent_list[i].fd);
return 0;
}
diff --git a/libkdenetwork/libgpgme-copy/gpgme/rungpg.c b/libkdenetwork/libgpgme-copy/gpgme/rungpg.c
index d09cdf3b6..42fff0032 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/rungpg.c
+++ b/libkdenetwork/libgpgme-copy/gpgme/rungpg.c
@@ -1211,7 +1211,7 @@ start (engine_gpg_t gpg)
int saved_errno;
int i, n;
int status;
- struct spawn_fd_item_s *fd_child_list, *fd_parent_list;
+ struct spawn_fd_item_s *fd_child_list, *fd_tqparent_list;
if (!gpg)
return gpg_error (GPG_ERR_INV_VALUE);
@@ -1247,7 +1247,7 @@ start (engine_gpg_t gpg)
fd_child_list = calloc (n + n, sizeof *fd_child_list);
if (!fd_child_list)
return gpg_error_from_errno (errno);
- fd_parent_list = fd_child_list + n;
+ fd_tqparent_list = fd_child_list + n;
/* build the fd list for the child */
n = 0;
@@ -1269,32 +1269,32 @@ start (engine_gpg_t gpg)
fd_child_list[n].fd = -1;
fd_child_list[n].dup_to = -1;
/* Build the fd list for the parent. */
n = 0;
if (gpg->status.fd[1] != -1)
{
- fd_parent_list[n].fd = gpg->status.fd[1];
- fd_parent_list[n].dup_to = -1;
+ fd_tqparent_list[n].fd = gpg->status.fd[1];
+ fd_tqparent_list[n].dup_to = -1;
n++;
}
if (gpg->colon.fd[1] != -1)
{
- fd_parent_list[n].fd = gpg->colon.fd[1];
- fd_parent_list[n].dup_to = -1;
+ fd_tqparent_list[n].fd = gpg->colon.fd[1];
+ fd_tqparent_list[n].dup_to = -1;
n++;
}
for (i = 0; gpg->fd_data_map[i].data; i++)
{
- fd_parent_list[n].fd = gpg->fd_data_map[i].peer_fd;
- fd_parent_list[n].dup_to = -1;
+ fd_tqparent_list[n].fd = gpg->fd_data_map[i].peer_fd;
+ fd_tqparent_list[n].dup_to = -1;
n++;
}
- fd_parent_list[n].fd = -1;
- fd_parent_list[n].dup_to = -1;
+ fd_tqparent_list[n].fd = -1;
+ fd_tqparent_list[n].dup_to = -1;
status = _gpgme_io_spawn (gpg->file_name ? gpg->file_name :
_gpgme_get_gpg_path (),
- gpg->argv, fd_child_list, fd_parent_list);
+ gpg->argv, fd_child_list, fd_tqparent_list);
saved_errno = errno;
free (fd_child_list);
if (status == -1)
@@ -1269,32 +1269,32 @@ start (engine_gpg_t gpg)
fd_child_list[n].fd = -1;
fd_child_list[n].dup_to = -1;
- /* Build the fd list for the parent. */
+ /* Build the fd list for the tqparent. */
n = 0;
if (gpg->status.fd[1] != -1)
diff --git a/libkdenetwork/libgpgme-copy/gpgme/wait-global.c b/libkdenetwork/libgpgme-copy/gpgme/wait-global.c
index ba064ebbd..bfa618dd1 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/wait-global.c
+++ b/libkdenetwork/libgpgme-copy/gpgme/wait-global.c
@@ -41,7 +41,7 @@
GPGME_EVENT_START event. After that, it is added to the global
list of active contexts.
- The gpgme_wait function tqcontains a select() loop over all file
+ The gpgme_wait function contains a select() loop over all file
descriptors in all active contexts. If an error occurs, it closes
all fds in that context and moves the context to the global done
list. Likewise, if a context has removed all I/O callbacks, it is
@@ -75,15 +75,15 @@ struct ctx_list_item
gpgme_error_t status;
};
/* The active list tqcontains all contexts that are in the global event
loop, have active I/O callbacks, and have already seen the start
event. */
static struct ctx_list_item *ctx_active_list;
/* The done list tqcontains all contexts that have previously been
active but now are not active any longer, either because they
finished successfully or an I/O callback returned an error. The
- status field in the list item tqcontains the error value (or 0 if
+ status field in the list item contains the error value (or 0 if
successful). */
static struct ctx_list_item *ctx_done_list;
@@ -75,15 +75,15 @@ struct ctx_list_item
gpgme_error_t status;
};
-/* The active list tqcontains all contexts that are in the global event
+/* The active list contains all contexts that are in the global event
loop, have active I/O callbacks, and have already seen the start
event. */
@@ -75,15 +75,15 @@ struct ctx_list_item
event. */
static struct ctx_list_item *ctx_active_list;
-/* The done list tqcontains all contexts that have previously been
+/* The done list contains all contexts that have previously been
active but now are not active any longer, either because they
finished successfully or an I/O callback returned an error. The